@@ -1,11 +1,10 @@
 # -*- coding: utf-8 -*-
-""" Find Cloud files on S3 within the 'iceberg-data-core' bucket """
+""" Find Cloud files on S3 within the a given bucket """
 
 
 import os
 
-from baseblock import EnvIO
-from baseblock import FileIO
+from baseblock import Enforcer
 from baseblock import Stopwatch
 from baseblock import BaseObject
 
@@ -14,15 +13,13 @@ from awsfile_helper import ReadFromCache
 from awsfile_helper import FileContentReader
 
 
-BUCKET_NAME = 'iceberg-data-core'
-
-
 class FindS3File(BaseObject):
-    """ Find Cloud files on S3 within the 'iceberg-data-core' bucket """
+    """ Find Cloud files on S3 within the a given bucket """
 
     __awsapi = None
 
     def __init__(self,
+                 bucket_name: str,
                  file_name: str,
                  file_ext: str,
                  file_version: str = None):
@@ -42,14 +39,27 @@ class FindS3File(BaseObject):
             craigtrim@gmail.com
             *   adhere to latest standard on file version
                 https://bast-ai.atlassian.net/browse/COR-59
+        Updated:
+            1-Nov-2022
+            craigtrim@gmail.com
+            *   remove hard-coded bucket names
+                https://github.com/craigtrim/awsfile-helper/issues/2
 
         Args:
+            bucket_name (str): the name of the bucket
             file_name (str): the qualified name of the file to retrieve
             file_ext (str): the file's extension
             file_version (str, optional): the file version. Defaults to '*'.
                 the default '*' will always retrieve the latest version
         """
         BaseObject.__init__(self, __name__)
+        if self.isEnabledForDebug:
+            Enforcer.is_str(bucket_name)
+            Enforcer.is_str(file_name)
+            Enforcer.is_str(file_ext)
+            Enforcer.is_optional_str(file_version)
+
+        self._bucket_name = bucket_name
         self._file_name = file_name
         self._file_ext = file_ext
         self._file_version = file_version
@@ -83,7 +93,7 @@ class FindS3File(BaseObject):
 
         if self._file_version == '*':
             self._file_version = self._awsapi().latest_version_number(
-                bucket_name=BUCKET_NAME,
+                bucket_name=self._bucket_name,
                 file_name=self._file_name)
 
         return self._file_version
@@ -119,7 +129,7 @@ class FindS3File(BaseObject):
                       file_version: str) -> dict:
         # access the training file from S3
         local_file_path = self._awsapi().file_by_version(
-            bucket_name=BUCKET_NAME,
+            bucket_name=self._bucket_name,
             file_name=self._file_name,
             file_ext=self._file_ext,
             version=file_version)
@@ -131,7 +141,7 @@ class FindS3File(BaseObject):
             self.logger.debug('\n'.join([
                 'Retrieved Cloud File',
                 f'\tTotal Time: {str(sw)}',
-                f'\tBucket Name: {BUCKET_NAME}',
+                f'\tBucket Name: {self._bucket_name}',
                 f'\tFile Version: {file_version}',
                 f'\tLocal Path: {local_file_path}']))
 
